/*
 * MSP2807_Startup_Screen_ASCII.c
 *
 *  Created on: 2025/02/25
 *      Author: Revive
 */

#include "MSP2807_Startup_Screen_ASCiI.h"

#include "Color_Code.h"
#include "ILI9341_SPI_Draw.h"
#include "ILI9341_Display_Clear.h"
#include "ILI9341_Display_ASCII.h"


//--------------------------------------------------------------
// MSP2807起動画面表示 : ASCII
//--------------------------------------------------------------
// 引数：
// uint8_t *puint8_JobNum : 処理番号を格納する変数のポインタ

// 戻り値：
//   -1 : 処理中
//    0 : OK終了
//    1 : NG終了
//--------------------------------------------------------------
int16_t MSP2807_Startup_Screen_ASCII(uint8_t *puint8_JobNum)
{
  static uint8_t STC_uint8_JobNum_LCD;  // LCD表示処理番号


  int16_t int16_Return;


  switch(*puint8_JobNum)
  {
  case 0:
    STC_uint8_JobNum_LCD = 0;  // LCD表示処理番号初期化


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 1:
    //--------------------------------------------------------------
    // 画面表示をクリアする。
    //--------------------------------------------------------------
    // 引数：
    // uint8_t *puint8_JobNum : 処理番号を格納する変数のポインタ

    // 戻り値：
    //   -1 : 処理中
    //    0 : OK
    //    1 : NG
    //-------------------------------------------------------------------------
    int16_Return = Clear_Display(&STC_uint8_JobNum_LCD);
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }

    if(int16_Return != 0){
      // NG
      *puint8_JobNum = 0;  // 処理番号初期化
      break;  // NG終了
    }


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 2:
    //--------------------------------------------------------------
    // font 8 x 8 : ASCII : "Welcome!"
    //--------------------------------------------------------------

    //--------------------------------------------------
    // 横長表示 左
    //--------------------------------------------------
    //--------------------------------------------------------------
    // LCD文字表示 : Font選択 : ILI9341 : ASCII
    //--------------------------------------------------------------
    // 引数：
    // uint8_t *puint8_JobNum : 処理番号を格納する変数のポインタ

    // int16_t int16_Check_Semaphore : セマフォチェック有無
    //    0 : チェックなし
    //    1 : チェックあり

    // uint16_t uint16_Font : font指定
    //    0 : 8 x 8 font : ASCII
    //    1 : 16 x 16 font : ASCII
    //    2 : 32 x 32 font : ASCII
    //    3 : 48 x 48 font : ASCII

    //    4 : 16 x 16 font : Unicode
    //    5 : 32 x 32 font : Unicode
    //    6 : 48 x 48 font : Unicode

    // uint8_t uint8_Oblong : 縦長/横長
    //    0 : Lengthwise : 縦長 左
    //    1 : Lengthwise : 縦長 右
    //    2 : WidthwiseL : 横長 左
    //    3 : WidthwiseR : 横長 右

    // uint8_t uint8_Type : 表示選択
    //      0 : 通常表示
    //      1 : 反転表示
    //      2 : 通常表示の上書き
    //      3 : 反転表示の上書き

    // uint32_t uint32_ColorCode : カラーコード

    // uint16_t uint16_StartX : 表示開始位置X
    // uint16_t uint16_StartY : 表示開始位置Y

    // uint16_t uint16_Length : 表示文字数
    // uint8_t *puint8_aData :
    //              表示文字コードが格納されているBufferのポインタ


    // 戻り値：
    //   -1 : 処理中
    //    0 : OK終了
    //    1 : NG終了
    //--------------------------------------------------------------
    int16_Return = ILI9341_SPI_Display_ASCII(&STC_uint8_JobNum_LCD,
                                        1,
                                    (uint16_t)def_Font_ASCII_8x8,
                                        def_WidthwiseL, 0,
                                        (uint32_t)def_Code_White,
                                        0, 0,
                                        8, (uint8_t *)"Welcome!");
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }

    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 3:
    //--------------------------------------------------------------
    // font 16 x 16 : ASCII : "Welcome!"
    //--------------------------------------------------------------

    //--------------------------------------------------
    // 横長表示 左
    //--------------------------------------------------
    int16_Return = ILI9341_SPI_Display_ASCII(&STC_uint8_JobNum_LCD,
                                        1,
                                (uint16_t)def_Font_ASCII_16x16,
                                        def_WidthwiseL, 0,
                                        (uint32_t)def_Code_Hotpink,
                                        64, 0,
                                        8, (uint8_t *)"Welcome!");
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 4:
    //------------------------------------------------
    // "Nice!" : 16 x 16 dot
    //------------------------------------------------
    //--------------------------------------------------
    // 横長表示 左
    //--------------------------------------------------
    int16_Return = ILI9341_SPI_Display_ASCII(&STC_uint8_JobNum_LCD,
                                        1,
                                        (uint16_t)def_Font_ASCII_16x16,
                                        def_WidthwiseL, 0,
                                        (uint32_t)def_Code_Blue,
                                        192, 0,
                                        5, (uint8_t *)"Nice!");
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 5:
    //------------------------------------------------
    // "ELEC" : 48 x 48 dot
    //------------------------------------------------
    //--------------------------------------------------
    // 縦長表示 左
    //--------------------------------------------------
    int16_Return = ILI9341_SPI_Display_ASCII(&STC_uint8_JobNum_LCD,
                                        1,
                            (uint16_t)def_Font_ASCII_Expand_48x48,
                                        def_LengthwiseL, 0,
                                        (uint32_t)def_Code_Cyan,
                                        0, 0,
                                        4, (uint8_t *)"ELEC");
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 6:
    //------------------------------------------------
    // "Good day!!" : 32 x 32 dot
    //------------------------------------------------
    //--------------------------------------------------
    // 横長表示 右
    //--------------------------------------------------
    int16_Return = ILI9341_SPI_Display_ASCII(&STC_uint8_JobNum_LCD,
                                        1,
                            (uint16_t)def_Font_ASCII_Expand_32x32,
                                        def_WidthwiseR, 0,
                                        (uint32_t)def_Code_Violet,
                                        0, 0,
                                        10, (uint8_t *)"Good day!!");
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 7:
    //------------------------------------------------
    // "ennui time." : 16 x 16 dot
    //------------------------------------------------
    //--------------------------------------------------
    // 横長表示 右
    //--------------------------------------------------
    int16_Return = ILI9341_SPI_Display_ASCII(&STC_uint8_JobNum_LCD,
                                    1,
                                    (uint16_t)def_Font_ASCII_16x16,
                                    def_LengthwiseR, 0,
                                    (uint32_t)def_Code_Brown,
                                    40, 0,
                                    11, (uint8_t *)"ennui time.");
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 8:
    //------------------------------------------------
    // "Take it easy..." : 16 x 16 dot
    //------------------------------------------------
    //--------------------------------------------------
    // 横長表示 左
    //--------------------------------------------------
    int16_Return = ILI9341_SPI_Display_ASCII(&STC_uint8_JobNum_LCD,
                                1,
                                (uint16_t)def_Font_ASCII_16x16,
                                def_WidthwiseL, 0,
                                (uint32_t)def_Code_Darkmagenta,
                                32, 32,
                                15, (uint8_t *)"Take it easy...");
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 9:
    //--------------------------------------------------------------
    // font 32 x 32 : ASCII : "Graph"
    //--------------------------------------------------------------

    //--------------------------------------------------
    // 横長表示 左
    //--------------------------------------------------
    int16_Return = ILI9341_SPI_Display_ASCII(&STC_uint8_JobNum_LCD,
                                        1,
                            (uint16_t)def_Font_ASCII_Expand_32x32,
                                        def_WidthwiseL, 0,
                                        (uint32_t)def_Code_Lime,
                                        64, 56,
                                        5, (uint8_t *)"Graph");
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 10:
    //--------------------------------------------------------------
    // font 16 x 16 : ASCII : "Bar graph"
    //--------------------------------------------------------------

    //--------------------------------------------------
    // 横長表示 右
    //--------------------------------------------------
    int16_Return = ILI9341_SPI_Display_ASCII(&STC_uint8_JobNum_LCD,
                                        1,
                                    (uint16_t)def_Font_ASCII_16x16,
                                        def_LengthwiseR, 0,
                                        (uint32_t)def_Code_Green,
                                        44, 20,
                                        9, (uint8_t *)"Bar graph");
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }

    
    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 11:
    //--------------------------------------------------------------
    // font 48 x 48 : ASCII : "Pi"
    //--------------------------------------------------------------

    //--------------------------------------------------
    // 横長表示 右
    //--------------------------------------------------
    int16_Return = ILI9341_SPI_Display_ASCII(&STC_uint8_JobNum_LCD,
                                        1,
                            (uint16_t)def_Font_ASCII_Expand_48x48,
                                        def_LengthwiseR, 0,
                                        (uint32_t)def_Code_Orange,
                                        36, 64,
                                        2, (uint8_t *)"Pi");
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }


    *puint8_JobNum = 0;  // 処理番号初期化
    int16_Return = 0;    // OK終了
    break;

  default:
    *puint8_JobNum = 0;  // 処理番号初期化
    int16_Return = 1;    // NG
    break;
  }

  return(int16_Return);
}
