/*
 * MSP2807_Test_ASCII.c
 *
 *  Created on: 2025/02/25
 *      Author: egaono-electronics
 */

#include "MSP2807_Test_ASCII.h"

#include "Color_Code.h"
#include "ILI9341_SPI_Init.h"
#include "MSP2807_Startup_Screen_ASCII.h"
#include "ILI9341_Display_ASCII.h"

#include "Time_Interval.h"



//--------------------------------------------------------------
// MSP2807試験 : ASCII文字表示 :
//                  Font配列使用 : プログラム埋め込み
//--------------------------------------------------------------
// 引数：
// uint8_t *puint8_JobNum : 処理番号が格納された変数のポインタ


// 戻り値：
//   -1 : 処理中
//    0 : OK終了
//    1 : NG終了
//--------------------------------------------------------------
int16_t MSP2807_Test_ASCII(uint8_t *puint8_JobNum)
{
  //----------------------------------------------------
  // 呼び出す関数の引数に使用する処理番号は、
  // 必ず static の変数宣言をしてください。
  //----------------------------------------------------
  static uint8_t STC_uint8_JobNum_Time;  // Time_Interval処理番号

  //--------------------------------------------------------
  // Time_Interval用パラメータの構造体の宣言は、
  // 使用する関数内で、必ず static で宣言してください。
  //--------------------------------------------------------
  // Time_Interval用パラメータの構造体の宣言
  //--------------------------------------------------------
  static struct sParam_Time_Interval STC_structParam_Time_Interval;


  static uint8_t STC_uint8_JobNum_MSP2807;  // MSP2807処理番号

  static uint16_t STC_uint16_Num;  // 数字
  static uint8_t STC_uint8_aString[4];  // 表示データの配列


  int16_t int16_Return;


  switch(*puint8_JobNum)
  {
  case 0:
    STC_uint8_JobNum_MSP2807 = 0;  // MSP2807処理番号初期化

    STC_uint16_Num = 0;  // 数字初期化


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 1:
    //----------------------------------------------------------
    // ILI9341初期化
    //----------------------------------------------------------
    // 戻り値：
    //   -1 : 処理中
    //    0 : OK
    //    1 : NG
    //----------------------------------------------------------
    int16_Return = ILI9341_Initialize(&STC_uint8_JobNum_MSP2807);
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }

    if(int16_Return != 0){
      // NG
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
      // 初期化が正常に終了しない場合、ここから下の処理に進まない。
    }


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 2:
    //----------------------------------------------------------
    // MSP2807起動画面表示 : ASCII
    //----------------------------------------------------------
    // 引数：
    // uint8_t *puint8_JobNum : 処理番号を格納する変数のポインタ

    // 戻り値：
    //   -1 : 処理中
    //    0 : OK終了
    //    1 : NG終了
    //----------------------------------------------------------
    int16_Return
        = MSP2807_Startup_Screen_ASCII(&STC_uint8_JobNum_MSP2807);
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }


    // 数字の文字列を初期化
    STC_uint8_aString[0] = (uint8_t)'0';
    STC_uint8_aString[1] = (uint8_t)'0';
    STC_uint8_aString[2] = (uint8_t)'0';
    STC_uint8_aString[3] = 0;


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 3:
    //----------------------------------------------------------
    // font 32 x 32 : ASCII : 数字を表示する。
    //----------------------------------------------------------

    //--------------------------------------------------
    // 横長表示 左
    //--------------------------------------------------
    //----------------------------------------------------------
    // LCD文字表示 : Font選択 : ILI9341
    //----------------------------------------------------------
    // 引数：
    // uint8_t *puint8_JobNum : 処理番号を格納する変数のポインタ

    // int16_t int16_Check_Semaphore : セマフォチェック有無
    //    0 : チェックなし
    //    1 : チェックあり

    // uint16_t uint16_Font : font指定
    //    0 : 8 x 8 font : ASCII
    //    1 : 16 x 16 font : ASCII
    //    2 : 32 x 32 font : ASCII
    //    3 : 48 x 48 font : ASCII

    // uint8_t uint8_Oblong : 縦長/横長
    //    0 : Lengthwise : 縦長 左
    //    1 : Lengthwise : 縦長 右
    //    2 : WidthwiseL : 横長 左
    //    3 : WidthwiseR : 横長 右

    // uint8_t uint8_Type : 表示選択
    //      0 : 通常表示
    //      1 : 反転表示
    //      2 : 通常表示の上書き
    //      3 : 反転表示の上書き

    // uint32_t uint32_ColorCode : カラーコード

    // uint16_t uint16_StartX : 表示開始位置X
    // uint16_t uint16_StartY : 表示開始位置Y

    // uint16_t uint16_Length : 表示文字数
    // uint8_t *puint8_aData :
    //          表示文字コードが格納されているBufferのポインタ


    // 戻り値：
    //   -1 : 処理中
    //    0 : OK終了
    //    1 : NG終了
    //----------------------------------------------------------
    int16_Return = ILI9341_SPI_Display_ASCII(
                            &STC_uint8_JobNum_MSP2807,
                            1,
                            (uint16_t)def_Font_ASCII_Expand_32x32,
                            def_WidthwiseL, 0,
                            (uint32_t)def_Code_White,
                            132, 128,
                            3, STC_uint8_aString);
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }


    STC_uint8_JobNum_Time = 0;  // Time_Interval処理番号初期化
    STC_structParam_Time_Interval.uint32_Interval = (uint32_t)1000;
                                // 待ち時間セット : 1000mSec


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 4:
    //----------------------------------------------------------
    // 時間待ち : 単位 mSec
    //----------------------------------------------------------
    // 戻り値が -1 以外になるまで、繰り返し呼び出してください。
    //----------------------------------------------------------
    // 引数:
    // uint8_t *puint8_JobNum : 処理番号を格納する変数のポインタ

    // struct sParam_Time_Interval *pstructParam_Time_Interval :
    //              Time_Interval用パラメータの構造体のポインタ


    // 戻り値:
    //   -1 : 処理中 : 時間が経過していない。
    //    0 : OK終了 : 時間が経過した。
    //    1 : NG終了
    //----------------------------------------------------------
    int16_Return = Time_Interval(&STC_uint8_JobNum_Time,
                                 &STC_structParam_Time_Interval);
    if(int16_Return == -1){
      // 処理中 : 時間未経過
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }


    STC_uint16_Num++;  // 数字をインクリメント
    if(STC_uint16_Num > 999){
      // 数字が 999 を越えたら 0 に戻す。 : 0 - 999 を繰り返す。
      STC_uint16_Num = 0;
    }

    //--------------------------------------------------------------
    // 数字を3桁の文字列に変換 : ASCII
    //--------------------------------------------------------------
    // 引数：
    // uint16_t uint16_Num : 数字

    // uint8_t *puint8_aString :
    //      3桁の文字列に変換したデータを格納するバッファのポインタ

    // 戻り値：
    //    なし
    //--------------------------------------------------------------
    Conv_Num_String_3_ASCII(STC_uint16_Num, STC_uint8_aString);


    (*puint8_JobNum)--;  // ひとつ前の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  default:
    *puint8_JobNum = 0;  // 処理番号初期化
    int16_Return = 1;    // NG
    break;
  }

  return(int16_Return);
}


//------------------------------------------------------------------
// 数字を3桁の文字列に変換 : ASCII
//------------------------------------------------------------------
// 引数：
// uint16_t uint16_Num : 数字

// uint8_t *puint8_aString :
//          3桁の文字列に変換したデータを格納するバッファのポインタ

// 戻り値：
//    なし
//------------------------------------------------------------------
void Conv_Num_String_3_ASCII(
                    uint16_t uint16_Num, uint8_t *puint8_aString)
{
  if(uint16_Num > 999){
    // NG
    return;
  }


  if(uint16_Num < 10){
    puint8_aString[0] = (uint8_t)'0';
    puint8_aString[1] = (uint8_t)'0';

    puint8_aString[2] = 0x30 | (uint8_t)uint16_Num;
  }
  else if(uint16_Num < 100){
    puint8_aString[0] = (uint8_t)'0';

    puint8_aString[1] = 0x30 | (uint8_t)(uint16_Num / 10);

    puint8_aString[2] = 0x30 | (uint8_t)(uint16_Num % 10);
  }
  else{
    puint8_aString[0] = 0x30 | (uint8_t)(uint16_Num / 100);

    puint8_aString[1] = 0x30 | (uint8_t)((uint16_Num / 10) % 10);

    puint8_aString[2] = 0x30 | (uint8_t)(uint16_Num % 10);
  }
}
